Index — Prime documentation

# Index

G | I | M | P | R | W

## G

get_n_prime() (in module primepackage.primemodule)

## I

is_prime() (in module primepackage.primemodule)

## M

module primepackage primepackage.primeio primepackage.primemodule

## P

primepackage module primepackage.primeio module | primepackage.primemodule module

## R

read_primes() (in module primepackage.primeio)

## W

write_primes() (in module primepackage.primeio)